#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Michael Verret (AxXium)
#last changed		: 13-september-2007

#package			: freedroidrpg
#homepage			: http://freedroid.sourceforge.net/

# ----- credentials
softname="freedroidrpg"
softversion="0.10.3"
srcurl="http://downloads.sourceforge.net/freedroid/freedroidrpg-0.10.3.tar.bz2"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest$prefix/bin
mkdir -p $dest$prefix/doc/$softname-$softversion
mkdir -p $dest$prefix/share/applications
mkdir -p $dest$prefix/share/icons/hicolor/48x48/apps
mkdir -p $dest$prefix/share/icons/hicolor/64x64/apps
mkdir -p $dest$prefix/share/icons/hicolor/72x72/apps
mkdir -p $dest$prefix/doc
mkdir -p $dest$prefix/man/man6
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
            |-----handy-ruler------------------------------------------------------|
freedroidrpg: freedroidrpg (role playing game)
freedroidrpg:
freedroidrpg: The Freedroid RPG is an extension/modification of the
freedroidrpg: classical Freedroid engine into an RPG. The main differences
freedroidrpg: to the classical version are as follows: The Tux is the main
freedroidrpg: character of the rpg, isometric viewpoint and animated
freedroidrpg: pre-rendered 3d character models, dialogs and chatting with
freedroidrpg: friendly droids and humans, an automap feature, saving and
freedroidrpg: loading of games, shops to trade things and skills to learn,
freedroidrpg: the mouse is the input method of choice and a more graphically
freedroidrpg: intense game.
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.bz2 ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -jxvf $softname-$softversion.tar.bz2
cd $srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure --prefix=$prefix
	
# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
cp -a \
	AUTHORS COPYING ChangeLog INSTALL NEWS README \
	$dest/usr/doc/$srcdir

# ----- treat icon-files
cd $builddir
if [ -f freedroidrpg-48.png ]; then
   echo "looking for 48x48 icon .. found"
else
   echo "looking for 48x48 icon .. none found"
   wget -c http://www.rapidrabbit.de/jj/zenwalk/icons/freedroidrpg-48.png
fi
if [ -f freedroidrpg-64.png ]; then
   echo "looking for 64x64 icon .. found"
else
   echo "looking for 64x64 icon .. none found"
   wget -c http://www.rapidrabbit.de/jj/zenwalk/icons/freedroidrpg-64.png
fi
if [ -f freedroidrpg-72.png ]; then
   echo "looking for 72x72 icon .. found"
else
   echo "looking for 72x72 icon .. none found"
   wget -c http://www.rapidrabbit.de/jj/zenwalk/icons/freedroidrpg-72.png
fi
cp freedroidrpg-48.png $dest/usr/share/icons/hicolor/48x48/apps/freedroidrpg.png
cp freedroidrpg-64.png $dest/usr/share/icons/hicolor/64x64/apps/freedroidrpg.png
cp freedroidrpg-72.png $dest/usr/share/icons/hicolor/72x72/apps/freedroidrpg.png

# ----- make .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=FreedroidRPG
Comment=Extension of the classical Freedroid engine into an RPG
Comment[de]=Erweiterung der ursprünglichen Freedroid-Engine zu einem RPG
Exec=freedroidRPG
Icon=freedroidrpg
Terminal=false
Type=Application
Categories=Game;RolePlaying;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
mv $dest/usr/share/man/man6/* $dest/usr/man/man6
rm -rf $dest/usr/share/man

for mandir in $(find . -name man -type d) ; do
	if [ -d $mandir ]; then
		( cd $mandir
		  find . -type f -name "*.?" -exec gzip -9 {} \;
		)
	fi
done
	
# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libogg,libpng,libtiff,libvorbis,mesa,ncurses,openssl,perl,sdl,sysfsutils,xorg,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
rm -r $builddir/official-names
fi
